@@ -4,12 +4,20 @@ import io
 import sys
 import unittest
 from types import TracebackType
-from typing import Iterable, TextIO, Tuple, Type, Union
+from typing import Iterable
+from typing import TextIO
+from typing import Tuple
+from typing import Type
+from typing import Union
 from unittest.case import TestCase
-from unittest.result import STDERR_LINE, STDOUT_LINE, failfast
+from unittest.result import failfast
+from unittest.result import STDERR_LINE
+from unittest.result import STDOUT_LINE
 
 from django.test import testcases
-from django.test.runner import DebugSQLTextTestResult, DiscoverRunner, PDBDebugResult
+from django.test.runner import DebugSQLTextTestResult
+from django.test.runner import DiscoverRunner
+from django.test.runner import PDBDebugResult
 from rich.color import Color
 from rich.console import Console
 from rich.rule import Rule
@@ -153,14 +161,14 @@ class RichPDBDebugResult(PDBDebugResult, RichTextTestResult):
     pass
 
 
-class RichTestRunner(DiscoverRunner.test_runner):
+class RichTestRunner(DiscoverRunner.test_runner):  # type: ignore [misc,valid-type]
     resultclass = RichTextTestResult
 
 
 class RichRunner(DiscoverRunner):
     test_runner = RichTestRunner
 
-    def get_resultclass(self) -> type[RichTextTestResult] | None:
+    def get_resultclass(self) -> type[unittest.TextTestResult] | None:
         if self.debug_sql:
             return RichDebugSQLTextTestResult
         elif self.pdb:
